======================
Django Hotsauce v0.6.2
======================

:Author: Etienne Robillard <tkadm30@yandex.com>
:Version: 0.6.2
:Last modified: 2017-01-23

Welcome to the django-hotsauce developer's handbook! This is a work-in-progress
document and may contains errors and/or incompleted chapters, etc. You're
invited to send feedback or suggestions about this document.

Thanks for reading!

.. toctree::

    :maxdepth: 3

    handbook/getting-started
    handbook/install
    handbook/configuration/advanced-configuration
    handbook/templates/mako
    handbook/cheatsheet

    reference/controllers/index
    reference/datastore
    reference/authentication/index
    reference/dbapi/schevo
    reference/urlmap

